@@ -25,20 +25,20 @@
 #include "kfind.h"
 
 #include <QDialog>
-#include <QtCore/QHash>
-#include <QtCore/QList>
-#include <QtCore/QPointer>
-#include <QtCore/QString>
+#include <QHash>
+#include <QList>
+#include <QPointer>
+#include <QString>
 
-struct KFind::Private {
+struct Q_DECL_HIDDEN KFind::Private {
     Private(KFind *q)
         : q(q)
-        , findDialog(0)
+        , findDialog(nullptr)
         , currentId(0)
         , customIds(false)
         , patternChanged(false)
         , matchedPattern(QLatin1String(""))
-        , emptyMatch(0)
+        , emptyMatch(nullptr)
     {
     }
 
@@ -47,10 +47,10 @@ struct KFind::Private {
         if (dialog) {
             dialog->deleteLater();
         }
-        dialog = 0;
+        dialog = nullptr;
         data.clear();
         delete emptyMatch;
-        emptyMatch = 0;
+        emptyMatch = nullptr;
     }
 
     struct Match {
